#include "calculator.h"

#define MIN_BUT_WIDTH 36
#define MIN_BUT_HEIGHT 36
#define NORMAL_FONT_SIZE 8
#define BIG_FONT_SIZE 12

Calculator::Calculator(QWidget *parent)
    : QWidget(parent)
{

    // vytvoreni hlavniho Grid Layoutu - rozmisteni komponent v okne
    layout = new QGridLayout;

    // panel pro display
    panel = new QVBoxLayout;
    display = new QLineEdit("0",this);
    display->setReadOnly(true);
    display->setAlignment( Qt::AlignRight);
    panel->addWidget(display);
    layout->addLayout(panel, 0, 0, 1, 4);

    //panel pro radiobuttony
    hbox = new QHBoxLayout();
    radioButtons = new QGroupBox(this);
    norRBut = new QRadioButton(QString("Normal"), radioButtons);
    bigRBut = new QRadioButton(QString("Big"), radioButtons);
    norRBut->setChecked(1);
    hbox->addWidget(norRBut);
    hbox->setSpacing(20);
    hbox->addWidget(bigRBut);
    hbox->setAlignment(Qt::AlignCenter);
    radioButtons->setLayout(hbox);
    radioButtons->setMaximumHeight(80);
    layout->addWidget(radioButtons, 1, 0, 1, 4);

    connect(norRBut,SIGNAL(clicked()),this,SLOT(clickNorButton()));
    connect(bigRBut,SIGNAL(clicked()),this,SLOT(clickBigButton()));
    
    //jednotliva tlacitka
    for(int i = 0; i <= 9; i++)
    {
        QPushButton* btn = new QPushButton(QString::number(i));

        btn->setMinimumSize(MIN_BUT_WIDTH, MIN_BUT_HEIGHT);
        btn->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        btn->setFont(QFont("SanSerif", NORMAL_FONT_SIZE, QFont::Normal));
        connect(btn, SIGNAL(clicked()), this, SLOT(clickDigit()));
        this->digitButtonList.push_back(btn);
    }

    layout->addWidget(this->digitButtonList[1], 5, 0);
    layout->addWidget(this->digitButtonList[5], 4, 1);
    layout->addWidget(this->digitButtonList[9], 3, 2);
    layout->addWidget(this->digitButtonList[0], 6, 0, 1, 2);


    addBut = new QPushButton("+");
    addBut->setMinimumSize(MIN_BUT_WIDTH, MIN_BUT_HEIGHT);
    addBut->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    connect(addBut, SIGNAL(clicked()), this, SLOT(clickOperator()));

    clsBut = new QPushButton("Cls");
    clsBut->setMinimumSize(MIN_BUT_WIDTH, MIN_BUT_HEIGHT);
    clsBut->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    connect(clsBut, SIGNAL(clicked()), this, SLOT(clickCls()));

    layout->addWidget(addBut, 3, 3);
    layout->addWidget(clsBut, 2, 0);

    setLayout( layout );
}

Calculator::~Calculator()
{

}

void Calculator::clickDigit()
{
    QPushButton *clickedButton = (QPushButton *)(sender());
    QString txt = display->text();
    if(txt.compare("0") == 0)
        txt = clickedButton->text();
    else
        txt.append(clickedButton->text());
    display->setText(txt);
}

void Calculator::clickOperator()
{
    QPushButton *clickedButton = (QPushButton *)(sender());
    QString txt = display->text();
    txt.append(clickedButton->text());
    display->setText(txt);
}

void Calculator::clickNorButton()
{
    clsBut->setFont(QFont("SanSerif", NORMAL_FONT_SIZE, QFont::Normal));

}
void Calculator::clickBigButton()
{
    clsBut->setFont(QFont("SanSerif", BIG_FONT_SIZE, QFont::Bold));
}

void Calculator::clickCls()
{
    display->setText("0");
}


